BenchmarkInfo class

Data class to hold benchmark information.

Constructors

BenchmarkInfo({required double initTimeInSecond, required double timeToFirstTokenInSecond, required int lastPrefillTokenCount, required int lastDecodeTokenCount, required double lastPrefillTokensPerSecond, required double lastDecodeTokensPerSecond})
Creates benchmark information.
const
BenchmarkInfo.fromJson(Map<String, Object?> json)
Creates benchmark information from JSON-compatible values.
factory
BenchmarkInfo.fromJsonString(String source)
Creates benchmark information from a JSON string.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
initTimeInSecond → double
The time in seconds to initialize the engine and the conversation.
final
lastDecodeTokenCount → int
The number of tokens in the last decode.
final
lastDecodeTokensPerSecond → double
The number of tokens processed per second in the last decode.
final
lastPrefillTokenCount → int
The number of tokens in the last prefill.
final
lastPrefillTokensPerSecond → double
The number of tokens processed per second in the last prefill.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeToFirstTokenInSecond → double
The time in seconds to the first token.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
Converts this benchmark information to JSON-compatible values.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited