Capabilities class

Provides information about capabilities supported by a LiteRT-LM file.

Constructors

Capabilities(String modelPath)
Loads capability information for the LiteRT-LM model at modelPath.

Properties

hashCode → int
The hash code for this object.
no setterinherited
isAlive → bool
Whether these capabilities are still loaded.
no setter
modelPath → String
The file path to the LiteRT-LM model.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → Future<void>
Releases loaded capability resources.
hasSpeculativeDecodingSupport() → bool
Whether the loaded LiteRT-LM file supports speculative decoding.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited