Backend class sealed

Backend for the LiteRT-LM engine.

Implementers

Constructors

Backend.cpu({int? threadCount})
CPU LiteRT backend.
const
factory
Backend.gpu()
GPU LiteRT backend.
const
factory
Backend.npu({String? nativeLibraryDir})
NPU LiteRT backend.
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
The backend name used by the native runtime.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Backend>
All backend values without additional configuration.