CpuBackend class

CPU LiteRT backend.

Inheritance

Constructors

CpuBackend({int? threadCount})
Creates a CPU backend configuration.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
The backend name used by the native runtime.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
threadCount → int?
The number of threads to use for the CPU backend.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited