EngineConfig class

Configuration for the LiteRT-LM engine.

Constructors

EngineConfig({required String modelPath, Backend backend = Backend.cpu, Backend? visionBackend, Backend? audioBackend, int? maxNumTokens, String? cacheDir, int? loraRank, int? audioLoraRank})
Creates an engine configuration.
const

Properties

audioBackend Backend?
The backend to use for the audio executor.
final
audioLoraRank int?
The supported rank for Audio LoRA weights.
final
backend Backend
The backend to use for the engine.
final
cacheDir String?
The directory for placing cache files.
final
hashCode int
The hash code for this object.
no setterinherited
loraRank int?
The supported rank for LoRA weights.
final
maxNumTokens int?
The maximum number of the sum of input and output tokens.
final
modelPath String
The file path to the LiteRT-LM model.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visionBackend Backend?
The backend to use for the vision executor.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited