isAlive property
bool
get
isAlive
Whether the conversation is alive and ready to be used.
Implementation
bool get isAlive => _handle != null;
Whether the conversation is alive and ready to be used.
bool get isAlive => _handle != null;