Engine class

Manages the lifecycle of a LiteRT-LM engine.

Constructors

Engine({required EngineConfig engineConfig})
Creates an engine with the given configuration.

Properties

engineConfig → EngineConfig
The configuration for the engine.
final
hashCode → int
The hash code for this object.
no setterinherited
isInitialized → bool
Whether the engine is initialized and ready for use.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createConversation([ConversationConfig conversationConfig = const ConversationConfig()]) → Future<Conversation>
Creates a new conversation from the initialized engine.
createSession([SessionConfig sessionConfig = const SessionConfig()]) → Future<Session>
Creates a new lower-level session from the initialized engine.
dispose() → Future<void>
Releases the native LiteRT-LM engine resources.
initialize() → Future<void>
Initializes the native LiteRT-LM engine.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited