isAlive property
bool
get
isAlive
Whether the session is alive and ready to use.
Implementation
bool get isAlive => _handle != null;
Whether the session is alive and ready to use.
bool get isAlive => _handle != null;