LiteRtLmNativeException class

Exception thrown when C++ escapes a native LiteRT-LM API boundary.

Inheritance
Implementers

Constructors

LiteRtLmNativeException(String message, LiteRtLmOperation operation, {required int code})
Creates a native exception for operation.
const

Properties

code int
Stable native error code, including codes unknown to this package version.
final
hashCode int
The hash code for this object.
no setterinherited
message String
The error message.
finalinherited
operation LiteRtLmOperation
Operation that encountered the native exception.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

outOfMemoryCode → const int
Native error code for allocation failure.
unexpectedExceptionCode → const int
Native error code for an otherwise unidentified C++ exception.