ExperimentalFlags class final

Experimental flags for LiteRT-LM.

These flags guard APIs that are not yet considered mature and may change or be removed without notice.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

conversationToolCallStreamingChannelName String
The Message.channels key used for streamed tool-call token fragments.
getter/setter pair
enableBenchmark bool
Whether benchmark collection is enabled.
getter/setter pair
enableConversationConstrainedDecoding bool
Whether conversation constrained decoding is enabled.
getter/setter pair
enableConversationToolCallStreaming bool
Whether tool-call tokens are emitted while responses are streaming.
getter/setter pair
enableSpeculativeDecoding bool?
Whether speculative decoding is enabled.
getter/setter pair
filterChannelContentFromKvCache bool
Whether channel content is filtered from the KV cache.
getter/setter pair
visualTokenBudget int?
The visual token budget.
getter/setter pair