enableConversationConstrainedDecoding property

bool get enableConversationConstrainedDecoding

Whether conversation constrained decoding is enabled.

This is primarily used for function calling.

This flag is read when a new Conversation is created. Changing this value does not affect existing Conversation instances.

Implementation

static bool get enableConversationConstrainedDecoding =>
    LiteRtLmNativeRuntime.instance.enableConversationConstrainedDecoding;
set enableConversationConstrainedDecoding (bool value)

Implementation

static set enableConversationConstrainedDecoding(bool value) {
  LiteRtLmNativeRuntime.instance.enableConversationConstrainedDecoding =
      value;
}