enableConversationToolCallStreaming property

bool get enableConversationToolCallStreaming

Whether tool-call tokens are emitted while responses are streaming.

Token fragments are emitted in Message.channels using conversationToolCallStreamingChannelName as the key. The runtime emits the complete call in Message.toolCalls when ready. With automatic tool calling enabled, the complete call is consumed and executed before being forwarded to the caller.

This flag is read when a new Conversation is created.

Implementation

static bool get enableConversationToolCallStreaming =>
    LiteRtLmNativeRuntime.instance.enableConversationToolCallStreaming;
set enableConversationToolCallStreaming (bool value)

Implementation

static set enableConversationToolCallStreaming(bool value) {
  LiteRtLmNativeRuntime.instance.enableConversationToolCallStreaming = value;
}