AudioFileContent class

Audio content provided by a file path.

Inheritance

Constructors

AudioFileContent(String path)
Creates audio content from a file path.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
path String
The audio file path.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Converts this content to JSON-compatible values.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited