ImageBytesContent class

Image content provided as raw bytes.

Inheritance

Constructors

ImageBytesContent(Uint8List bytes)
Creates image content from raw bytes.
const

Properties

bytes Uint8List
The image bytes.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Converts this content to JSON-compatible values.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited