Role enum

The role of the message in a conversation.

Inheritance
Available extensions

Values

system → const Role

Represents the system.

const Role('system')
user → const Role

Represents the user.

const Role('user')
model → const Role

Represents the model.

const Role('model')
tool → const Role

Represents a tool response.

const Role('tool')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
jsonName → String
The JSON role name.
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJsonName(String? name) → Role
Creates a role from a JSON role name.

Constants

values → const List<Role>
A constant List of the values in this enum, in order of their declaration.