ToolCall class

Tool call returned by the model.

Constructors

ToolCall({required String name, required Map<String, Object?> arguments})
Creates a tool call.
const
ToolCall.fromJson(Map<String, Object?> json)
Creates a tool call from JSON-compatible values.
factory

Properties

arguments Map<String, Object?>
The arguments for the tool function.
final
hashCode int
The hash code for this object.
no setterinherited
name String
The name of the tool function to execute.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Converts this tool call to JSON-compatible values.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited