ToolResponseContent class

Tool response provided by the user.

Inheritance

Constructors

ToolResponseContent({required String name, required Object? response})
Creates tool response content.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
The name of the tool.
final
response Object?
The tool response.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Converts this content to JSON-compatible values.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited