AudioInputData class

Audio input data.

Inheritance

Constructors

AudioInputData(Uint8List bytes)
Creates audio input data.
const

Properties

bytes Uint8List
The audio bytes.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Converts this input data to JSON-compatible values.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited