InputData class sealed

Input data for the lower-level LiteRT-LM session API.

Implementers

Constructors

InputData.audioBytes(Uint8List bytes)
Audio input bytes. Supported formats depend on the model, commonly WAV.
factory
InputData.imageBytes(Uint8List bytes)
Image input bytes. Supported formats depend on the model, commonly PNG and JPEG.
factory
InputData.text(String text)
Text input.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Converts this input data to JSON-compatible values.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited