Tool class abstract interface

A tool that can be used by the LiteRT-LM model.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

execute(Map<String, Object?> arguments) FutureOr<Object?>
Executes the tool with the given arguments.
getToolDescription() Map<String, Object?>
Gets the tool description in function schema format.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited