ToolManager class

Manages tools and provides methods to execute tools and get their specifications.

Constructors

ToolManager({List<Tool> tools = const []})
Creates a tool manager with the given tools.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolsJsonDescription String
The tools description for all tools.
no setter

Methods

execute({required String name, required Map<String, Object?> arguments}) Future<Object?>
Executes a tool function by its name with the given arguments.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited