getTokenCount abstract method
Gets the number of tokens in the conversation KV Cache.
Implementation
Future<int> getTokenCount(ConversationHandle conversation);
Gets the number of tokens in the conversation KV Cache.
Future<int> getTokenCount(ConversationHandle conversation);