Channel class
Definition of a channel for model responses.
Constructors
Properties
- channelName → String
-
The channel name used as the key in Message.channels.
final
- end → String
-
A string that marks the end of the channel.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- start → String
-
A string that marks the start of the channel.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Converts this channel to JSON-compatible values.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited