ConversationConfig class
Configuration for a LiteRT-LM conversation.
Constructors
-
ConversationConfig({Message? systemMessage, List<
Message> initialMessages = const [], List<Tool> tools = const [], Map<String, Object?> extraContext = const {}, SamplerConfig? samplerConfig, String? loraPath, String? audioLoraPath, bool automaticToolCalling = true, bool enableConstrainedDecoding = false}) -
Creates a conversation configuration.
const
Properties
- audioLoraPath → String?
-
Optional file path to the Audio LoRA weights file.
final
- automaticToolCalling → bool
-
Whether tools will be called automatically.
final
- enableConstrainedDecoding → bool
-
Whether constrained decoding is enabled.
final
-
extraContext
→ Map<
String, Object?> -
Optional context passed to prompt template rendering.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
initialMessages
→ List<
Message> -
The initial messages for the conversation.
final
- loraPath → String?
-
Optional file path to the LoRA weights file.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- samplerConfig → SamplerConfig?
-
Configuration for the sampling process.
final
- systemMessage → Message?
-
The system message for the conversation.
final
-
tools
→ List<
Tool> -
A list of tool objects to be used in the conversation.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Converts this configuration to JSON-compatible values.
-
toJsonString(
) → String - Converts this configuration to a JSON string.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited