ConversationConfig class

Configuration for a LiteRT-LM conversation.

Constructors

ConversationConfig({Message? systemMessage, List<Message> initialMessages = const [], List<Tool> tools = const [], Map<String, Object?> extraContext = const {}, SessionConfig? sessionConfig, bool automaticToolCalling = true, List<Channel>? channels, bool enableConstrainedDecoding = false})
Creates a conversation configuration.
const

Properties

automaticToolCalling bool
Whether tools will be called automatically.
final
channels List<Channel>?
Channel definitions for model output, or null to use model defaults.
final
enableConstrainedDecoding bool
Whether constrained decoding is enabled.
final
extraContext Map<String, Object?>
Optional context passed to prompt template rendering.
final
hashCode int
The hash code for this object.
no setterinherited
initialMessages List<Message>
The initial messages for the conversation.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionConfig SessionConfig?
Configuration for the session backing this conversation.
final
systemMessage Message?
The system message for the conversation.
final
tools List<Tool>
A list of tool objects to be used in the conversation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Converts this configuration to JSON-compatible values.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited