ConversationConfig class
Constructors
-
ConversationConfig({Contents? systemInstruction, List<
Message> initialMessages = const [], List<Tool> tools = const [], Map<String, Object?> extraContext = const {}, SessionConfig? sessionConfig}) -
const
Properties
-
extraContext
→ Map<
String, Object?> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
initialMessages
→ List<
Message> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionConfig → SessionConfig?
-
final
- systemInstruction → Contents?
-
final
-
tools
→ List<
Tool> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toJsonString(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited