SamplerConfig class

Configuration for the sampling process.

Constructors

SamplerConfig({required int topK, required double topP, required double temperature, int seed = 0})
Creates a sampler configuration.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seed int
The seed to use for randomization.
final
temperature double
The temperature to use for sampling.
final
topK int
The number of top logits used during sampling.
final
topP double
The cumulative probability threshold for nucleus sampling.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Converts this configuration to JSON-compatible values.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited