SessionConfig class

Configuration for a LiteRT-LM session.

Constructors

SessionConfig({SamplerConfig? samplerConfig, LoraConfig? loraConfig})
Creates a session configuration.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
loraConfig LoraConfig?
Configuration for LoRA weights.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
samplerConfig SamplerConfig?
Configuration for the sampling process.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Converts this configuration to JSON-compatible values.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited