Conversation class

Properties

hashCode int
The hash code for this object.
no setterinherited
isAlive bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel() Future<void>
dispose() Future<void>
getTokenCount() Future<int>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
renderMessageIntoString(Message message) Future<String>
sendMessage(Message message, {Map<String, Object?>? extraContext}) Future<Message>
sendMessageStream(Message message, {Map<String, Object?>? extraContext}) Stream<Message>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited