Session class
Lower-level LiteRT-LM session API.
Properties
Methods
-
cancelProcess(
) → void - Cancels any ongoing session processing.
-
dispose(
) → Future< void> - Releases native session resources.
-
generateContent(
List< InputData> inputData) → Future<String> - Generates content from the given input data.
-
generateContentStream(
List< InputData> inputData) → Stream<String> - Generates content from the given input data and streams text chunks.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
runDecode(
) → Future< String> - Runs the decode step and returns the generated text.
-
runPrefill(
List< InputData> inputData) → Future<void> - Runs the prefill step for the given input data.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited