LiteRtLmOutOfMemoryException class final

Exception thrown when a native LiteRT-LM allocation fails.

Inheritance

Constructors

LiteRtLmOutOfMemoryException(LiteRtLmOperation operation)
Creates an out-of-memory exception for operation.
const

Properties

code → int
Stable native error code, including codes unknown to this package version.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
message → String
The error message.
finalinherited
operation → LiteRtLmOperation
Operation that encountered the native exception.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited