enableBenchmark property
bool
get
enableBenchmark
Whether benchmark collection is enabled.
This flag is read when a new Engine is created. Changing this value does not affect existing Engine or Conversation instances.
Implementation
static bool get enableBenchmark =>
LiteRtLmNativeRuntime.instance.enableBenchmark;
set
enableBenchmark
(bool value)
Implementation
static set enableBenchmark(bool value) {
LiteRtLmNativeRuntime.instance.enableBenchmark = value;
}