filterChannelContentFromKvCache property
bool
get
filterChannelContentFromKvCache
Whether channel content is filtered from the KV cache.
If true, channel content (e.g. reasoning) will be filtered from the KV cache.
Note: This flag is read only when a new Conversation is created. Changing this value will not affect any existing Conversation instances.
Implementation
static bool get filterChannelContentFromKvCache =>
LiteRtLmNativeRuntime.instance.filterChannelContentFromKvCache;
set
filterChannelContentFromKvCache
(bool value)
Implementation
static set filterChannelContentFromKvCache(bool value) {
LiteRtLmNativeRuntime.instance.filterChannelContentFromKvCache = value;
}