Content class sealed
Constructors
- Content.audioBytes(Uint8List bytes)
-
factory
- Content.audioFile(String path)
-
factory
-
Content.fromJson(Map<
String, Object?> json) -
factory
- Content.imageBytes(Uint8List bytes)
-
factory
- Content.imageFile(String path)
-
factory
- Content.text(String text)
-
factory
- Content.toolResponse({required String name, required Object? response})
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited