Contents class

Constructors

Contents(List<Content> values)
const
Contents.fromJson(Object? json)
factory
Contents.single(Content content)
factory
Contents.text(String text)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
no setter
values List<Content>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toJsonString() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

empty → const Contents