Tool class
Constructors
-
Tool({required String name, required String description, List<
ToolParameter> parameters = const []}) -
const
Properties
- description → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
-
parameters
→ List<
ToolParameter> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toJsonString(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited