ToolParameter class
Constructors
- ToolParameter({required String name, required ToolParameterType type, String description = '', bool required = true, bool nullable = false, ToolParameterType? itemType})
-
const
Properties
- description → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemType → ToolParameterType?
-
final
- name → String
-
final
- nullable → bool
-
final
- required → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → ToolParameterType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited