LiteRtLmNativeRuntime class abstract interface

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancelConversation(ConversationHandle conversation) → void
createConversation(EngineHandle engine, ConversationConfig config) Future<ConversationHandle>
createEngine(EngineConfig config) EngineHandle
deleteConversation(ConversationHandle conversation) → void
deleteEngine(EngineHandle engine) → void
getTokenCount(ConversationHandle conversation) Future<int>
initializeEngine(EngineHandle engine) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
renderMessageIntoString(ConversationHandle conversation, String messageJson) Future<String>
sendMessage(ConversationHandle conversation, String messageJson, {String? extraContextJson}) Future<Message>
sendMessageStream(ConversationHandle conversation, String messageJson, {String? extraContextJson}) Stream<Message>
setMinimumLogLevel(LogSeverity severity) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance LiteRtLmNativeRuntime
final